import Errors from './Errors';
import Request from './Request';
export declare enum FormMethods {
    POST = "post",
    PATCH = "patch",
    PUT = "put"
}
export interface FormConfig {
    resetAfterSend?: boolean;
    removeNullValues?: boolean;
    method?: FormMethods;
    request?: Request;
}
export interface FormProperties {
    [key: string]: any;
}
export default class Form {
    [key: string]: any;
    private readonly originalData;
    private readonly config;
    errors: Errors;
    private request;
    /**
     * Create a new Form instance.
     */
    constructor(data: FormProperties, config?: FormConfig);
    /**
     * Add a new field with value to the form.
     */
    addField(field: string, value: any): void;
    /**
     * Serialize the Form.
     */
    serialize(asString?: boolean): string | object;
    /**
     * Submit the form.
     */
    submit(url: string): Promise<any>;
    /**
     * Get FormData object.
     */
    getFormData(): FormData;
    /**
     * Reset the state of the form to the original state and clears errors.
     */
    private reset;
    private addArray;
    private addObject;
}
